@@ -13,13 +13,18 @@
 draw.cov.matrix <- function(my.matrix, fun = stats::cov, ...) {
   cov.matrix           <- fun(my.matrix, ...)
   rownames(cov.matrix) <- colnames(cov.matrix)
-  cov.matrix           <- data.frame(cov.matrix)
-  cov.df               <- cbind(x = colnames(cov.matrix), cov.matrix)
-  cov.melt             <- reshape2::melt(cov.df, id.vars = c('x'), variable.name = 'y', value.name = 'Values')
+
+  cov.matrix <- data.frame(cov.matrix)
+  cov.df     <- cbind(x = colnames(cov.matrix), cov.matrix)
+  cov.melt   <- reshape2::melt(
+    cov.df, id.vars = c('x'), variable.name = 'y', value.name = 'Values'
+  )
 
   #
   return(
-    ggplot2::ggplot(cov.melt, ggplot2::aes_(x = quote(x), y = quote(y), fill = quote(Values))) +
+    ggplot2::ggplot(
+      cov.melt, ggplot2::aes_(x = quote(x), y = quote(y), fill = quote(Values))
+    ) +
       ggplot2::geom_raster() +
       ggplot2::scale_fill_continuous(low='#56B1F7', high = '#132B43') +
       ggplot2::theme_minimal() +
