@@ -1,7 +1,7 @@
 context("synthetic")
 
 test_that("Covariance matrix is respected", {
-  for(ix in 1:10) {
+  for(ix in seq(10)) {
     n.vars <- ceiling(runif(1, min = 10, max = 99))
     diagonal.of.ones <-diag(cov(gen.synth.xdata(n.obs = 100, n.vars = n.vars, rho = runif(1))))
     expect_equal(diagonal.of.ones, rep(1, n.vars))
@@ -9,7 +9,7 @@ test_that("Covariance matrix is respected", {
 })
 
 test_that("Covariance matrix is not respected due to more variables than observations", {
-  for(n.vars in 1:10) {
+  for(n.vars in seq(10)) {
     n.obs <- ceiling(runif(1, min = 10, max = 99))
     expect_warning(xdata <- gen.synth.xdata(n.obs = n.obs, n.vars = 100, rho = runif(1)))
     #
@@ -22,7 +22,7 @@ test_that('Covariance parameter is respected', {
   cov.param <- .2
   xdata1 <- gen.synth.xdata(10, 5, cov.param)
   xdata1.cov <- cov(xdata1)
-  expect_true(all(sapply(1:ncol(xdata1), function(ix) {
+  expect_true(all(sapply(seq(ncol(xdata1)), function(ix) {
     result <- TRUE
     if (ix > 1) {
       result <- result && (abs(xdata1.cov[ix,ix-1] - cov.param) < 1e-14)
